@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.22';
 
 use File::Copy;
 use File::Path;
@@ -194,6 +194,8 @@ sub cp {
 
     _confirm("cp $_[0] $_[1]") or return 1;
 
+    INFO "cp $_[0] $_[1]";
+
     File::Copy::copy @_ or 
         get_logger("")->logcroak("Cannot copy $_[0] to $_[1] ($!)");
 }
@@ -214,6 +216,8 @@ sub mv {
 
     _confirm("mv $_[0] $_[1]") or return 1;
 
+    INFO "mv $_[0] $_[1]";
+
     File::Copy::move @_ or 
         get_logger("")->logcroak("Cannot move $_[0] to $_[1] ($!)");
 }
@@ -233,6 +237,8 @@ sub download {
 
     local($Log::Log4perl::caller_depth) += 1;
 
+    INFO "download $_[0]";
+
     _confirm("Downloading $_[0] => ", basename($_[0])) or return 1;
 
     getstore($_[0], basename($_[0])) or 
@@ -443,6 +449,8 @@ sub mkd {
 
     _confirm "mkd @_" or return 1;
 
+    INFO "mkpath @_";
+
     mkpath @_ or 
         get_logger("")->logcroak("Cannot mkdir @_ ($!)");
 }
@@ -469,6 +477,8 @@ sub rmf {
         return;
     }
 
+    INFO "rmtree @_";
+
     rmtree $_[0] or 
         get_logger("")->logcroak("Cannot rmtree $_[0] ($!)");
 }
@@ -530,6 +540,8 @@ sub make {
 
     _confirm "make @_" or return 1;
 
+    INFO "make @_";
+
     system("make @_") and 
         get_logger("")->logcroak("Cannot make @_ ($!)");
 }
